xds_b = {}

require 'ihe'
require 'ihe.xml'
require 'ihe.help'

local GetUUIDHelp = {
   title="xds_b.getUUID",
   usage="xds_b.getUUID()",
   description="This function will generate a new GUID.",
   returns={
      "The created GUID"
   },
   parameters={},
   examples={"local GUID = xds_b.getUUID()"}
}

function xds_b.getUUID()
   return util.guid(128)
end

ihe.help.set{func=xds_b.getUUID, info=GetUUIDHelp}

local GetHTTPHeadersHelp = {
   title="xds_b.getHTTPHeaders",
   usage="xds_b.getHTTPHeaders{action=<value>}",
   description="Creates the HTTP headers needed to send a XDS_b Web service request.",
   returns="The created HTTP headers as well UUID's used in the headers",
   parameters={
      action="The type of request the headers refer to"
   },
   examples={[[local HTTPHeaders, ContentUUID, MimeUUID =
      xds_b.getHTTPHeaders{action='ProvideAndRegisterDocumentSet-b'}]]}
}

function xds_b.getHTTPHeaders(I)
   ihe.help.check(I, GetHTTPHeadersHelp)
   
   local Headers = {
      ['Content-Type'] = 'multipart/related; '..
                         'boundary=MIMEBoundaryurn_uuid_MIMEUUID; '..
                         'type="application/xop+xml"; '..
                         'start="<0.urn:uuid:CONTENTUUID>"; '..
                         'start-info="application/soap+xml"; '..
                         'action="urn:ihe:iti:2007:ACTION"'
   }
   
   local MimeUUID = xds_b.getUUID()
   local ContentUUID = xds_b.getUUID()
   
   
   Headers['Content-Type'] = Headers['Content-Type']:gsub('MIMEUUID', MimeUUID)
   Headers['Content-Type'] = Headers['Content-Type']:gsub('CONTENTUUID', ContentUUID)
   Headers['Content-Type'] = Headers['Content-Type']:gsub('ACTION', I.action)
   
   return Headers, ContentUUID, MimeUUID
end

ihe.help.set{func=xds_b.getHTTPHeaders, info=GetHTTPHeadersHelp}